# ethmeet
'ethmeet' stands for 'Ethical Meeting'.
>
Video-communication webdriver library. API compatible with most famous platforms.

## Installation
Pip:
```shell script
pip3 install ethmeet && python3 /usr/local/bin/gecko_install.py
```
> NOTE: ethmeet uses Firefox as its standard browser

## Docs
- [ethmeet Basic Usage & API Reference](https://github.com/elleaech/ethmeet/blob/master/docs/ethmeet.md)

## Contributing & Issue Tracker
Branch & [Pull Request](https://github.com/elleaech/ethmeet/pulls)
- [Issues](https://github.com/elleaech/ethmeet/issues)

### Get source
```shell script
git clone git@github.com:elleaech/ethmeet.git && cd ethmeet

python3 -m virtualenv . && pip3 install -r requirements.txt
```

## License
[Apache License 2.0](https://github.com/elleaech/ethmeet/blob/master/LICENSE)
